<?
//////////////////////////////////////////////////////////////////////
////
////  MAHC - MAHC Advanced Html Chat Version 1.0.0
////  Complex Chat System Written in PHP4 Supporting HTML-only clients
////  Copyright (C) 2001 Joseph Durbin <jdurbin@users.sourceforge.net>
////  This Source is GNU GPL, See file LICENSE in distribution.
////
//////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////
// PROGRAM NAME: chess.php
// AUTHOR: Joe Durbin
// DESCRIPTION: Web-based, 2 player Chess Game Component for MAHC
// FILES & DESCRIPTIONS:
//   chess.php  - PHP4 Main Program File ($USERNAME & $OPPONENT are only external variables needed)
//   help/chess.help - PHP4 Help Text for Program
//   data/$user-$user.chess - Custom Data File For Current Game Data Between 2 Users 
// 
// DATE: 11/17/2000 chess.php VERSION: 1.0 CHANGES: First Version
//
////////////////////////////////////////////////////////////////
	//// Verify Current Session ID Code. (prevent Hijacking of ID!)
	include("verifysessioncode.inc");
	VerifySessionCode($USERNAME,$CODE);

	function Setup($username,$opponent) {  //Alphabetise players, and setup basic variables
		global $Player,$GameInPlay,$PlayersTurn,$PlayerScore,$PlayerWhoStartedGame,$CurrentWinner,$Mode,$SelX,$SelY;
		if ($username<$opponent) {
			$Player[1]=$username;  //R(ed)
			$Player[2]=$opponent;  //W(hite)
		} else {
			$Player[1]=$opponent;  //R
			$Player[2]=$username;  //W
		};	
		$PlayersTurn=1;
		$PlayerScore[1]=0;  //R
		$PlayerScore[2]=0;  //W
	}

	function ResetData() {  //Reset gameboard data and switch playersturn to opposite that started last game.
		global $Player,$GameInPlay,$PlayersTurn,$PlayerScore,$PlayerWhoStartedGame,$CurrentWinner,$Mode,$SelX,$SelY;
		for ($i=1; $i<=8; $i++)
			for ($j=1; $j<=8; $j++) {
				$Board[$i][$j]=" ";
				if ($j==2) $Board[$i][$j]="p";  //Red Pawn
				if ($j==7) $Board[$i][$j]="P";  //White Pawn
			} 
		$Board[1][1]="r"; //Red Rook
		$Board[2][1]="b"; //Red Bishop
		$Board[3][1]="n"; //Red Knight
		$Board[4][1]="k"; //Red King
		$Board[5][1]="q"; //Red Queen
		$Board[6][1]="n"; //Red Knight
		$Board[7][1]="b"; //Red Bishop
		$Board[8][1]="r"; //Red Rook
		$Board[1][8]="R"; //White Rook
		$Board[2][8]="B"; //White Bishop
		$Board[3][8]="N"; //White Knight
		$Board[4][8]="K"; //White King
		$Board[5][8]="Q"; //White Queen
		$Board[6][8]="N"; //White Knight
		$Board[7][8]="B"; //White Bishop
		$Board[8][8]="R"; //White Rook

		if ($PlayerWhoStartedGame==1) $PlayerWhoStartedGame=2; else $PlayerWhoStartedGame=1;
		$PlayersTurn=$PlayerWhoStartedGame; 
		$GameInPlay=1;
		$CurrentWinner=0;
		$Mode=1;
		$SelX=0; $SelY=0;
		return $Board;
	}
	function WriteData($Board) {   //write game data file
		global $Player,$GameInPlay,$PlayersTurn,$PlayerScore,$PlayerWhoStartedGame,$CurrentWinner,$Mode,$SelX,$SelY;
		$DataFile=fopen("data/$Player[1]-$Player[2].chess","w");
		if (!($DataFile)) die("Could not open Game Data File!!!");
		fputs($DataFile,"$GameInPlay:$PlayersTurn:$PlayerScore[1]:$PlayerScore[2]:$PlayerWhoStartedGame:$CurrentWinner:$Mode:$SelX:$SelY\n");
		for ($i=1; $i<=8; $i++) {
			for ($j=1; $j<=8; $j++) {
				if ($Board[$j][$i]=="") $Board[$j][$i]=" ";
				fputs($DataFile,"{$Board[$j][$i]}:");
			};
			fputs($DataFile,"\n");
		};
		fclose($DataFile);
	}
	function LoadData() {   //read game data file
		global $Player,$GameInPlay,$PlayersTurn,$PlayerScore,$PlayerWhoStartedGame,$CurrentWinner,$Mode,$SelX,$SelY;
		$DataFile=fopen("data/$Player[1]-$Player[2].chess","r");
		if (!($DataFile)) die("Could not openGame Data File!!!");
		$Line		=	fgetcsv($DataFile,255,":");
		$GameInPlay	=	$Line[0];
		$PlayersTurn	=	$Line[1];
		$PlayerScore[1]	=	$Line[2];
		$PlayerScore[2]	=	$Line[3];
		$PlayerWhoStartedGame=	$Line[4];
		$CurrentWinner	=	$Line[5];
		$Mode		=	$Line[6];
		$SelX		=	$Line[7];
		$SelY		=	$Line[8];
		for ($i=1; $i<=8; $i++) {
			$Line=fgetcsv($DataFile,255,":");
			for ($j=1; $j<=8; $j++) {
				$Board[$j][$i]=$Line[$j-1];
				if ($Board[$j][$i]=="") $Board[$j][$i]=" ";
			}
		}
		fclose($DataFile);
		return $Board;
	}
	
	function MovePiece($Board, $x,$y) {  // Move game piece
		global $Player,$GameInPlay,$PlayersTurn,$PlayerScore,$PlayerWhoStartedGame,$CurrentWinner,$Mode,$SelX,$SelY;
		$Board[$x][$y]=$Board[$SelX][$SelY];  //copy piece to new position
		$Board[$SelX][$SelY]=" ";   //remove from old position.
		if (($Board[$x][$y]=="p")&&($y==8)) $Board[$x][$y]="q";   //Queening
		if (($Board[$x][$y]=="P")&&($y==1)) $Board[$x][$y]="Q";
		return $Board;
	}

	function ToggleTurn() {
		global $Player,$GameInPlay,$PlayersTurn,$PlayerScore,$PlayerWhoStartedGame,$CurrentWinner,$Mode,$SelX,$SelY;
		if ($PlayersTurn==1) $PlayersTurn=2; else $PlayersTurn=1;
		$Mode=1;
	}

	function CheckWinner($Board) { //Returns 0=no winner; 1=1stplayer; 2=2nd player
		global $Player,$GameInPlay,$PlayersTurn,$PlayerScore,$PlayerWhoStartedGame,$CurrentWinner,$Mode,$SelX,$SelY;
		$RedCount=0; $WhiteCount=0;
		for ($i=1; $i<=8; $i++) { 
			for ($j=1; $j<=8; $j++) {
				if ($Board[$j][$i]=="k") ++$RedCount;
				if ($Board[$j][$i]=="K") ++$WhiteCount;
			}
		}
		if ($WhiteCount==0) $CurrentWinner=1;
		if ($RedCount==0) $CurrentWinner=2;
		++$PlayerScore[$CurrentWinner];
	}

	function Background() {  // makes tiles checkered
		static $EveryOther;
		if ($EveryOther==0) {
			$EveryOther=1;
			$Back="222222";
		} else {
			$EveryOther=0;
			$Back="0000CC";
		};
		return $Back;
	}
	function AnalyzeMoves($Board,$x,$y) {  // Provide possible move data
		global $Player,$GameInPlay,$PlayersTurn,$PlayerScore,$PlayerWhoStartedGame,$CurrentWinner,$Mode,$SelX,$SelY;
		//MoveData[X possible move][Y possible move]
		$NumMoves=0;
		if ($Board[$x][$y]=="p") {  //RED PAWN POSSIBLE MOVE ANALYZATION
			if ($y<=7)
				if ($Board[$x][$y+1]==" ") {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x;
					$MoveData[$NumMoves][1]=$y+1;
					if (($Board[$x][$y+2]==" ")&&($y==2)) {
						++$NumMoves;
	                                        $MoveData[$NumMoves][0]=$x;
        	                                $MoveData[$NumMoves][1]=$y+2;						
					}
				}
			if (($y<=7)&&($x>=2))
				if (ereg("^[A-Z]{1}$",$Board[$x-1][$y+1])) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x-1;
					$MoveData[$NumMoves][1]=$y+1;
				}
			if (($y<=7)&&($x<=7))
				if (ereg("^[A-Z]{1}$",$Board[$x+1][$y+1])) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x+1;
					$MoveData[$NumMoves][1]=$y+1;
				}
		}
		if ($Board[$x][$y]=="P") {  //WHITE PAWN POSSIBLE MOVE ANALYZATION
			if ($y>=2)
				if ($Board[$x][$y-1]==" ") {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x;
					$MoveData[$NumMoves][1]=$y-1;
					if (($Board[$x][$y-2]==" ")&&($y==7)) {
						++$NumMoves;
	                                        $MoveData[$NumMoves][0]=$x;
        	                                $MoveData[$NumMoves][1]=$y-2;						
					}
				}
			if (($y>=2)&&($x>=2))
				if (ereg("^[a-z]{1}$",$Board[$x-1][$y-1])) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x-1;
					$MoveData[$NumMoves][1]=$y-1;
				}
			if (($y>=2)&&($x<=7))
				if (ereg("^[a-z]{1}$",$Board[$x+1][$y-1])) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x+1;
					$MoveData[$NumMoves][1]=$y-1;
				}
		}

		$Vectors[0][0]= 0; $Vectors[0][1]=-1; 
		$Vectors[1][0]= 1; $Vectors[1][1]= 0; 
		$Vectors[2][0]= 0; $Vectors[2][1]= 1; 
		$Vectors[3][0]=-1; $Vectors[3][1]= 0; 
		$Vectors[4][0]= 1; $Vectors[4][1]=-1; 
		$Vectors[5][0]= 1; $Vectors[5][1]= 1; 
		$Vectors[6][0]=-1; $Vectors[6][1]= 1; 
		$Vectors[7][0]=-1; $Vectors[7][1]=-1; 

		if ($Board[$x][$y]=="r") {  //RED ROOK POSSIBLE MOVE ANALYZATION
			for ($i=0; $i<=3; ++$i) {
				$j=1; 
				while (($Board[$x+($Vectors[$i][0]*$j)][$y+($Vectors[$i][1]*$j)]==" ")&&($x+($Vectors[$i][0]*$j)>=1)&&
				($x+($Vectors[$i][0]*$j)<=8)&&($y+($Vectors[$i][1]*$j)>=1)&&($y+($Vectors[$i][1]*$j)<=8)) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x+($Vectors[$i][0]*$j);
					$MoveData[$NumMoves][1]=$y+($Vectors[$i][1]*$j);
					++$j;	
				}
				if ((ereg("^[A-Z]{1}$",$Board[$x+($Vectors[$i][0]*$j)][$y+($Vectors[$i][1]*$j)]))&&($x+($Vectors[$i][0]*$j)>=1)&&
				($x+($Vectors[$i][0]*$j)<=8)&&($y+($Vectors[$i][1]*$j)>=1)&&($y+($Vectors[$i][1]*$j)<=8)) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x+($Vectors[$i][0]*$j);
					$MoveData[$NumMoves][1]=$y+($Vectors[$i][1]*$j);
					++$j;	
				}
			}
		}
		if ($Board[$x][$y]=="b") {  //RED BISHOP POSSIBLE MOVE ANALYZATION
			for ($i=4; $i<=7; ++$i) {
				$j=1; 
				while (($Board[$x+($Vectors[$i][0]*$j)][$y+($Vectors[$i][1]*$j)]==" ")&&($x+($Vectors[$i][0]*$j)>=1)&&
				($x+($Vectors[$i][0]*$j)<=8)&&($y+($Vectors[$i][1]*$j)>=1)&&($y+($Vectors[$i][1]*$j)<=8)) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x+($Vectors[$i][0]*$j);
					$MoveData[$NumMoves][1]=$y+($Vectors[$i][1]*$j);
					++$j;	
				}
				if ((ereg("^[A-Z]{1}$",$Board[$x+($Vectors[$i][0]*$j)][$y+($Vectors[$i][1]*$j)]))&&($x+($Vectors[$i][0]*$j)>=1)&&
				($x+($Vectors[$i][0]*$j)<=8)&&($y+($Vectors[$i][1]*$j)>=1)&&($y+($Vectors[$i][1]*$j)<=8)) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x+($Vectors[$i][0]*$j);
					$MoveData[$NumMoves][1]=$y+($Vectors[$i][1]*$j);
					++$j;	
				}
			}
		}
		if ($Board[$x][$y]=="n") {  //RED KNIGHT POSSIBLE MOVE ANALYZATION
			for ($i=4; $i<=7; ++$i) {
				if (($Board[$x+($Vectors[$i][0]*1)][$y+($Vectors[$i][1]*2)]==" ")&&($x+($Vectors[$i][0]*1)>=1)&&
				($x+($Vectors[$i][0]*1)<=8)&&($y+($Vectors[$i][1]*2)>=1)&&($y+($Vectors[$i][1]*2)<=8)) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x+($Vectors[$i][0]*1);
					$MoveData[$NumMoves][1]=$y+($Vectors[$i][1]*2);	
				}
				if ((ereg("^[A-Z]{1}$",$Board[$x+($Vectors[$i][0]*1)][$y+($Vectors[$i][1]*2)]))&&($x+($Vectors[$i][0]*1)>=1)&&
				($x+($Vectors[$i][0]*1)<=8)&&($y+($Vectors[$i][1]*2)>=1)&&($y+($Vectors[$i][1]*2)<=8)) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x+($Vectors[$i][0]*1);
					$MoveData[$NumMoves][1]=$y+($Vectors[$i][1]*2);	
				}
				if (($Board[$x+($Vectors[$i][0]*2)][$y+($Vectors[$i][1]*1)]==" ")&&($x+($Vectors[$i][0]*2)>=1)&&
				($x+($Vectors[$i][0]*2)<=8)&&($y+($Vectors[$i][1]*1)>=1)&&($y+($Vectors[$i][1]*1)<=8)) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x+($Vectors[$i][0]*2);
					$MoveData[$NumMoves][1]=$y+($Vectors[$i][1]*1);	
				}
				if ((ereg("^[A-Z]{1}$",$Board[$x+($Vectors[$i][0]*2)][$y+($Vectors[$i][1]*1)]))&&($x+($Vectors[$i][0]*2)>=1)&&
				($x+($Vectors[$i][0]*2)<=8)&&($y+($Vectors[$i][1]*1)>=1)&&($y+($Vectors[$i][1]*1)<=8)) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x+($Vectors[$i][0]*2);
					$MoveData[$NumMoves][1]=$y+($Vectors[$i][1]*1);	
				}
			}
		}

		if ($Board[$x][$y]=="q") {  //RED QUEEN POSSIBLE MOVE ANALYZATION
			for ($i=0; $i<=7; ++$i) {
				$j=1; 
				while (($Board[$x+($Vectors[$i][0]*$j)][$y+($Vectors[$i][1]*$j)]==" ")&&($x+($Vectors[$i][0]*$j)>=1)&&
				($x+($Vectors[$i][0]*$j)<=8)&&($y+($Vectors[$i][1]*$j)>=1)&&($y+($Vectors[$i][1]*$j)<=8)) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x+($Vectors[$i][0]*$j);
					$MoveData[$NumMoves][1]=$y+($Vectors[$i][1]*$j);
					++$j;	
				}
				if ((ereg("^[A-Z]{1}$",$Board[$x+($Vectors[$i][0]*$j)][$y+($Vectors[$i][1]*$j)]))&&($x+($Vectors[$i][0]*$j)>=1)&&
				($x+($Vectors[$i][0]*$j)<=8)&&($y+($Vectors[$i][1]*$j)>=1)&&($y+($Vectors[$i][1]*$j)<=8)) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x+($Vectors[$i][0]*$j);
					$MoveData[$NumMoves][1]=$y+($Vectors[$i][1]*$j);
					++$j;	
				}
			}
		}
		if ($Board[$x][$y]=="k") {  //RED KING POSSIBLE MOVE ANALYZATION
			for ($i=0; $i<=7; ++$i) {
				$j=1; 
				if (($Board[$x+($Vectors[$i][0]*$j)][$y+($Vectors[$i][1]*$j)]==" ")&&($x+($Vectors[$i][0]*$j)>=1)&&
				($x+($Vectors[$i][0]*$j)<=8)&&($y+($Vectors[$i][1]*$j)>=1)&&($y+($Vectors[$i][1]*$j)<=8)) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x+($Vectors[$i][0]*$j);
					$MoveData[$NumMoves][1]=$y+($Vectors[$i][1]*$j);
					//++$j;	
				}
				if ((ereg("^[A-Z]{1}$",$Board[$x+($Vectors[$i][0]*$j)][$y+($Vectors[$i][1]*$j)]))&&($x+($Vectors[$i][0]*$j)>=1)&&
				($x+($Vectors[$i][0]*$j)<=8)&&($y+($Vectors[$i][1]*$j)>=1)&&($y+($Vectors[$i][1]*$j)<=8)) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x+($Vectors[$i][0]*$j);
					$MoveData[$NumMoves][1]=$y+($Vectors[$i][1]*$j);
					++$j;	
				}
			}
		}
////////////////////////////////////////////WHITE VECTOR PIECES
		if ($Board[$x][$y]=="R") {  //WHITE ROOK POSSIBLE MOVE ANALYZATION
			for ($i=0; $i<=3; ++$i) {
				$j=1; 
				while (($Board[$x+($Vectors[$i][0]*$j)][$y+($Vectors[$i][1]*$j)]==" ")&&($x+($Vectors[$i][0]*$j)>=1)&&
				($x+($Vectors[$i][0]*$j)<=8)&&($y+($Vectors[$i][1]*$j)>=1)&&($y+($Vectors[$i][1]*$j)<=8)) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x+($Vectors[$i][0]*$j);
					$MoveData[$NumMoves][1]=$y+($Vectors[$i][1]*$j);
					++$j;	
				}
				if ((ereg("^[a-z]{1}$",$Board[$x+($Vectors[$i][0]*$j)][$y+($Vectors[$i][1]*$j)]))&&($x+($Vectors[$i][0]*$j)>=1)&&
				($x+($Vectors[$i][0]*$j)<=8)&&($y+($Vectors[$i][1]*$j)>=1)&&($y+($Vectors[$i][1]*$j)<=8)) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x+($Vectors[$i][0]*$j);
					$MoveData[$NumMoves][1]=$y+($Vectors[$i][1]*$j);
					++$j;	
				}
			}
		}
		if ($Board[$x][$y]=="B") {  //WHITE BISHOP POSSIBLE MOVE ANALYZATION
			for ($i=4; $i<=7; ++$i) {
				$j=1; 
				while (($Board[$x+($Vectors[$i][0]*$j)][$y+($Vectors[$i][1]*$j)]==" ")&&($x+($Vectors[$i][0]*$j)>=1)&&
				($x+($Vectors[$i][0]*$j)<=8)&&($y+($Vectors[$i][1]*$j)>=1)&&($y+($Vectors[$i][1]*$j)<=8)) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x+($Vectors[$i][0]*$j);
					$MoveData[$NumMoves][1]=$y+($Vectors[$i][1]*$j);
					++$j;	
				}
				if ((ereg("^[a-z]{1}$",$Board[$x+($Vectors[$i][0]*$j)][$y+($Vectors[$i][1]*$j)]))&&($x+($Vectors[$i][0]*$j)>=1)&&
				($x+($Vectors[$i][0]*$j)<=8)&&($y+($Vectors[$i][1]*$j)>=1)&&($y+($Vectors[$i][1]*$j)<=8)) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x+($Vectors[$i][0]*$j);
					$MoveData[$NumMoves][1]=$y+($Vectors[$i][1]*$j);
					++$j;	
				}
			}
		}
		if ($Board[$x][$y]=="N") {  //WHITE KNIGHT POSSIBLE MOVE ANALYZATION
			for ($i=4; $i<=7; ++$i) {
				if (($Board[$x+($Vectors[$i][0]*1)][$y+($Vectors[$i][1]*2)]==" ")&&($x+($Vectors[$i][0]*1)>=1)&&
				($x+($Vectors[$i][0]*1)<=8)&&($y+($Vectors[$i][1]*2)>=1)&&($y+($Vectors[$i][1]*2)<=8)) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x+($Vectors[$i][0]*1);
					$MoveData[$NumMoves][1]=$y+($Vectors[$i][1]*2);	
				}
				if ((ereg("^[a-z]{1}$",$Board[$x+($Vectors[$i][0]*1)][$y+($Vectors[$i][1]*2)]))&&($x+($Vectors[$i][0]*1)>=1)&&
				($x+($Vectors[$i][0]*1)<=8)&&($y+($Vectors[$i][1]*2)>=1)&&($y+($Vectors[$i][1]*2)<=8)) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x+($Vectors[$i][0]*1);
					$MoveData[$NumMoves][1]=$y+($Vectors[$i][1]*2);	
				}
				if (($Board[$x+($Vectors[$i][0]*2)][$y+($Vectors[$i][1]*1)]==" ")&&($x+($Vectors[$i][0]*2)>=1)&&
				($x+($Vectors[$i][0]*2)<=8)&&($y+($Vectors[$i][1]*1)>=1)&&($y+($Vectors[$i][1]*1)<=8)) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x+($Vectors[$i][0]*2);
					$MoveData[$NumMoves][1]=$y+($Vectors[$i][1]*1);	
				}
				if ((ereg("^[a-z]{1}$",$Board[$x+($Vectors[$i][0]*2)][$y+($Vectors[$i][1]*1)]))&&($x+($Vectors[$i][0]*2)>=1)&&
				($x+($Vectors[$i][0]*2)<=8)&&($y+($Vectors[$i][1]*1)>=1)&&($y+($Vectors[$i][1]*1)<=8)) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x+($Vectors[$i][0]*2);
					$MoveData[$NumMoves][1]=$y+($Vectors[$i][1]*1);	
				}
			}
		}
		if ($Board[$x][$y]=="Q") {  //WHITE QUEEN POSSIBLE MOVE ANALYZATION
			for ($i=0; $i<=7; ++$i) {
				$j=1; 
				while (($Board[$x+($Vectors[$i][0]*$j)][$y+($Vectors[$i][1]*$j)]==" ")&&($x+($Vectors[$i][0]*$j)>=1)&&
				($x+($Vectors[$i][0]*$j)<=8)&&($y+($Vectors[$i][1]*$j)>=1)&&($y+($Vectors[$i][1]*$j)<=8)) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x+($Vectors[$i][0]*$j);
					$MoveData[$NumMoves][1]=$y+($Vectors[$i][1]*$j);
					++$j;	
				}
				if ((ereg("^[a-z]{1}$",$Board[$x+($Vectors[$i][0]*$j)][$y+($Vectors[$i][1]*$j)]))&&($x+($Vectors[$i][0]*$j)>=1)&&
				($x+($Vectors[$i][0]*$j)<=8)&&($y+($Vectors[$i][1]*$j)>=1)&&($y+($Vectors[$i][1]*$j)<=8)) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x+($Vectors[$i][0]*$j);
					$MoveData[$NumMoves][1]=$y+($Vectors[$i][1]*$j);
					++$j;	
				}
			}
		}
		if ($Board[$x][$y]=="K") {  //WHITE KING POSSIBLE MOVE ANALYZATION
			for ($i=0; $i<=7; ++$i) {
				$j=1; 
				if (($Board[$x+($Vectors[$i][0]*$j)][$y+($Vectors[$i][1]*$j)]==" ")&&($x+($Vectors[$i][0]*$j)>=1)&&
				($x+($Vectors[$i][0]*$j)<=8)&&($y+($Vectors[$i][1]*$j)>=1)&&($y+($Vectors[$i][1]*$j)<=8)) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x+($Vectors[$i][0]*$j);
					$MoveData[$NumMoves][1]=$y+($Vectors[$i][1]*$j);
					//++$j;	
				}
				if ((ereg("^[a-z]{1}$",$Board[$x+($Vectors[$i][0]*$j)][$y+($Vectors[$i][1]*$j)]))&&($x+($Vectors[$i][0]*$j)>=1)&&
				($x+($Vectors[$i][0]*$j)<=8)&&($y+($Vectors[$i][1]*$j)>=1)&&($y+($Vectors[$i][1]*$j)<=8)) {
					++$NumMoves;
					$MoveData[$NumMoves][0]=$x+($Vectors[$i][0]*$j);
					$MoveData[$NumMoves][1]=$y+($Vectors[$i][1]*$j);
					++$j;	
				}
			}
		}


		$MoveData[0][0]=$NumMoves;
		if ($NumMoves==0) $Mode=1;
		return $MoveData;
	}
	
	function Piece($CHAR) {
		if (ereg("^[a-z]{1}$",$CHAR)) {
			$CHAR=strtoupper($CHAR);
			$CHAR="<FONT COLOR=RED>".$CHAR."</FONT>";
		} else if (ereg("^[A-Z]{1}$",$CHAR)) {
			$CHAR="<FONT COLOR=WHITE>".$CHAR."</FONT>";
		}
		return $CHAR;
	}

//////////////////////////////////////////[ BEGIN GAME ]/////////////////////////////////
Setup($USERNAME,$OPPONENT);

if (file_exists("data/$Player[1]-$Player[2].chess")) {
	$Board=LoadData();
} else {
	$Board=ResetData();
	WriteData($Board);
};	

if ($RESET==1) {
	$Board=ResetData();
	WriteData($Board);
}

include("managecurrentusers.inc");
if (GetPartner($OPPONENT)!=$USERNAME) {
	print("<HTML><CENTER><FONT SIZE=+2 COLOR=RED>$OPPONENT Has Closed The Game.<BR>To Exit, Click ");
	print ("<A HREF=\"welcome.php?USERNAME=$USERNAME&CODE=$CODE&CLOSE=1\" TARGET=LEFT>HERE</A>.</HTML>");
	exit();
}    

if ($HELP==1) {
	require("help/chess.help");
	exit();
}  

if (($Mode==1)&&($X>0)&&($Y>0)&&($Player[$PlayersTurn]==$USERNAME)) {
	$Mode=2;
	$SelX=$X;
	$SelY=$Y;
	WriteData($Board);
};

if (($Mode==2)&&($Player[$PlayersTurn]==$USERNAME)) {
	$MoveData=AnalyzeMoves($Board,$SelX,$SelY);
	if ($Mode==1) {
		$SelX=0; $SelY=0;
		WriteData($Board);
	}
}

if (($Mode==2)&&($X>0)&&($Y>0)&&(isset($MOVE))&&($Player[$PlayersTurn]==$USERNAME)) {
	$Board=MovePiece($Board,$X,$Y);
	CheckWinner($Board);
	ToggleTurn();
	WriteData($Board);
};

if ($Player[$PlayersTurn]==$USERNAME) $MyTurn=1; Else $MyTurn=0;
?>

<HTML><HEAD>
<? 
	if ($MyTurn==1) $Refresh=15; else $Refresh=7;
	print("<meta http-equiv=\"refresh\" content=\"$Refresh;URL=chess.php?USERNAME=$USERNAME&OPPONENT=$OPPONENT&CODE=$CODE\">");
?>
</HEAD><BODY BGCOLOR=FFFFFF HLINK=BLUE VLINK=BLUE ALINK=BLUE>
<CENTER>
<B><FONT SIZE=+2 COLOR=BLUE>CHESS<BR>
<? print("$Player[1] vs. $Player[2]"); ?>
<BR></FONT>
<FONT SIZE=+1>
- <? 
if ($CurrentWinner==0) { 
	print ("$Player[$PlayersTurn]'s turn");
	if ($Mode==1) print"(Choosing Piece)";
	if ($Mode==2) print"(Choosing Move)";
} else print ("<FONT COLOR=RED SIZE=+2>$Player[$CurrentWinner] wins the game!</FONT>");
?> -
<BR>
<TABLE BORDER=8 CELLPADDING=5 CELLSPACING=1>
<? 

for ($i=1; $i<=8; $i++) {
	print "<TR>";
	for ($j=1; $j<=8; $j++) {
		print "<TD BGCOLOR=".Background()."><FONT SIZE=+2>&nbsp;";
		if ($Mode==1) {
			if (($MyTurn==1)&&($PlayersTurn==1)&&(ereg("^[a-z]{1}$",$Board[$j][$i]))) 
				print ("<A HREF=\"chess.php?USERNAME=$USERNAME&OPPONENT=$OPPONENT&X=$j&Y=$i&CODE=$CODE\">".Piece($Board[$j][$i])."</A>");
			else if (($MyTurn==1)&&($PlayersTurn==2)&&(ereg("^[A-Z]{1}$",$Board[$j][$i]))) 
				print ("<A HREF=\"chess.php?USERNAME=$USERNAME&OPPONENT=$OPPONENT&X=$j&Y=$i&CODE=$CODE\">".Piece($Board[$j][$i])."</A>");
			else print (Piece($Board[$j][$i]));
		}
		if ($Mode==2) {
			if ($MyTurn==1) {
				$found=0;
				for ($k=1; $k<=$MoveData[0][0]; $k++) {
					if (($MoveData[$k][0]==$j)&&($MoveData[$k][1]==$i)) {
						print ("<A HREF=\"chess.php?USERNAME=$USERNAME&OPPONENT=$OPPONENT&X=$j&Y=$i&MOVE=1&CODE=$CODE\">");
						if ($PlayersTurn==1) print ("<FONT COLOR=RED>[</FONT>".Piece($Board[$j][$i])."<FONT COLOR=RED>]</FONT></A>");
						else print ("<FONT COLOR=WHITE>[</FONT>".Piece($Board[$j][$i])."<FONT COLOR=WHITE>]</FONT></A>");
						$found=1;
					}
				}
				if ($found==0) print (Piece($Board[$j][$i]));
			} else print (Piece($Board[$j][$i]));
		}
		print "&nbsp;</TD>";
	};
	Background();
	print"</TR>";
};
?>
</TABLE>
<BR>
<A HREF="welcome.php?USERNAME=<? print"$USERNAME&CODE=$CODE"; ?>&CLOSE=1" TARGET=LEFT>
CLOSE GAME</A> - 
<? print ("<A HREF=\"chess.php?USERNAME=$USERNAME&OPPONENT=$OPPONENT&CODE=$CODE&RESET=1\">"); ?>
NEW GAME</A> - 
<? print ("<A HREF=\"chess.php?USERNAME=$USERNAME&OPPONENT=$OPPONENT&CODE=$CODE&HELP=1\">"); ?>
HELP</A>
<BR></FONT>
OVERALL SCORE:  
<? print("$Player[1](Red) $PlayerScore[1] games; $Player[2](White) $PlayerScore[2] games"); ?>
<BR>

</CENTER></BODY></HTML>
